@@ -611,6 +611,9 @@ enum zd1205_device_type {
 ***************************************************************************/
 struct driver_stats {
 	struct net_device_stats net_stats;
+	#ifdef CONFIG_NET_WIRELESS
+	 struct iw_statistics iw_stats;
+	#endif
 	unsigned long tx_late_col;
 	unsigned long tx_ok_defrd;
 	unsigned long tx_one_retry;
