@@ -1882,7 +1882,10 @@ int zd1211_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd)
 
 #define	ZD1211_TX_TIMEOUT	(HZ*10)
 #define	ZD1211_MTU			1500
-extern struct iw_handler_def p80211wext_handler_def;
+#ifdef CONFIG_NET_WIRELESS
+ extern struct iw_handler_def p80211wext_handler_def;
+ extern struct iw_statistics *zd1205wext_iw_get_stats(struct net_device *);
+#endif
 
 u8 zd1211_InitSetup(struct net_device *dev, struct zd1205_private *macp)
 
@@ -1974,6 +1977,7 @@ u8 zd1211_InitSetup(struct net_device *dev, struct zd1205_private *macp)
 
 #if WIRELESS_EXT > 12
     dev->wireless_handlers = (struct iw_handler_def *)&p80211wext_handler_def;
+    dev->get_wireless_stats = &zd1205wext_iw_get_stats;
 #endif
     
 	dev->hard_start_xmit = zd1205_xmit_frame;
