@@ -6,7 +6,7 @@
 #endif
 
 /* Define these values to match your device */
-#define VENDOR_ZYDAS	0x0ACE  //ZyDAS; Edimax EW-7317Ug
+#define VENDOR_ZYDAS	0x0ACE  //ZyDAS; Edimax EW-7317Ug; AirLink+ AWLL3025
 #define PRODUCT_1211	0x1211
 #define VENDOR_ZYXEL	0x0586  //ZyXEL
 #define PRODUCT_G220	0x3401
@@ -14,6 +14,10 @@
 #define PRODUCT_UR055G	0x0711
 #define VENDOR_SITECOM	0x0DF6 //Sitecom WL-113
 #define PRODUCT_WL113	0x9071
+#define VENDOR_AOPEN	0x07B8 //AOpen 802.11g WL54
+#define PRODUCT_WL54	0x6001
+
+
 
 
 #endif
